.. currentmodule:: pycares

#################################
Welcome to pycares documentation!
#################################

Python interface for c-ares.

pycares is a Python module which provides an interface to c-ares.
c-ares (http://c-ares.haxx.se/) c-ares is a C library that performs
DNS requests and name resolves asynchronously.


Contents
########

.. toctree::
    :maxdepth: 3
    :titlesonly:

    pycares


ToDo
####

.. toctree::
    :maxdepth: 1

    TODO


Indices and tables
##################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

